# Showcase companion code

This folder contains code that is referenced in [Expert Showcases](https://si-tesseract.discourse.group/c/showcase/expert-showcase/12) on the Tesseract Forum. Please refer to the Forum for more context on each subdirectory.

> [!WARNING]
> While we generally aim for compatibility with future versions of Tesseract,
> please beware that the code contained here is not covered by tests and may be out of date.
> In case you run into incompatibilities, please [open an issue](https://github.com/pasteurlabs/tesseract-core/issues/new/choose).
